# New Blog: Finally Static!

I've been wanting to convert my website from a WordPress-powered application to a static one for a long time now. I tried a few different systems, but nothing was flexible enough for my needs.

I almost sat down and wrote something myself, but luckly I found Alex Metaireau's incredible Pelican project. So, now my website is statically generated with a combination of all my favorite tools: ReStructured Text, Jinja2, Python, Git, and Jenkins.

The move is far from perfect, but I'm glad I finally did it. All existing comments are gone. There's no longer a mobile version. Many of the old blog posts are malformed (and a big chunk should just be removed entirely).

But, these things will happen in time. It feels good to start fresh.

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter